@@ -105,7 +105,7 @@ VisualizerCallableInterface = Union[
 ]
 
 LeapData = Union[LeapImage, LeapText, LeapGraph, LeapHorizontalBar, LeapImageMask, LeapTextMask, LeapImageWithBBox,
-LeapImageWithHeatmap]
+LeapImageWithHeatmap, LeapVideo]
 
 CustomCallableInterface = Callable[..., Any]
 
