@@ -19,7 +19,8 @@ from code_loader.contract.enums import DataStateEnum, TestingSectionEnum, DataSt
 from code_loader.contract.exceptions import DatasetScriptException
 from code_loader.contract.responsedataclasses import DatasetIntegParseResult, DatasetTestResultPayload, \
     DatasetPreprocess, DatasetSetup, DatasetInputInstance, DatasetOutputInstance, DatasetMetadataInstance, \
-    VisualizerInstance, PredictionTypeInstance, ModelSetup, CustomLayerInstance, MetricInstance, CustomLossInstance
+    VisualizerInstance, PredictionTypeInstance, ModelSetup, CustomLayerInstance, MetricInstance, CustomLossInstance, \
+    EngineFileContract
 from code_loader.inner_leap_binder import global_leap_binder
 from code_loader.leaploaderbase import LeapLoaderBase
 from code_loader.utils import get_root_exception_file_and_line_number
@@ -179,7 +180,8 @@ class LeapLoader(LeapLoaderBase):
         return DatasetIntegParseResult(is_valid=is_valid, payloads=test_payloads,
                                        is_valid_for_model=is_valid_for_model, setup=setup_response,
                                        model_setup=model_setup, general_error=general_error,
-                                       print_log=print_log)
+                                       print_log=print_log,
+                                       engine_file_contract=EngineFileContract(global_leap_binder.mapping_connections))
 
     def _check_preprocess(self) -> DatasetTestResultPayload:
         test_result = DatasetTestResultPayload('preprocess')
@@ -204,8 +206,9 @@ class LeapLoader(LeapLoaderBase):
         preprocess_result = self._preprocess_result()
         result_payloads: List[DatasetTestResultPayload] = []
         dataset_base_handlers: List[Union[DatasetBaseHandler, MetadataHandler]] = self._get_all_dataset_base_handlers()
-        assert sum(isinstance(x, MetadataHandler) for x in dataset_base_handlers) < 100, "Metadata handles must be less than 100"
-        metadata_length = 0
+        metadata_handlers_num = sum(isinstance(x, MetadataHandler) for x in dataset_base_handlers)
+        assert metadata_handlers_num < 100, f"More than 100 metadata function are not allowed, current metadata function discovered: {metadata_handlers_num}"
+        metadata_param_count = 0
         for dataset_base_handler in dataset_base_handlers:
             test_result = [DatasetTestResultPayload(dataset_base_handler.name)]
             for state, preprocess_response in preprocess_result.items():
@@ -221,8 +224,8 @@ class LeapLoader(LeapLoaderBase):
                         state_name] = f"{repr(e)} in file {file_name}, line_number:  {line_number}\nStacktrace:\n{stacktrace}"
                     test_result[0].is_passed = False
             if isinstance(dataset_base_handler, MetadataHandler):
-                metadata_length += len(test_result)
-                assert metadata_length < 800, "Total number of metadata columns handles must be less than 800"
+                metadata_param_count += len(test_result)
+                assert metadata_param_count < 800, f"More than 800 metadata keys are not allowed, current metadata keys discovered: {metadata_param_count}"
             result_payloads.extend(test_result)
         return result_payloads
 
